UserDefinedFunction
===================

.. toctree::
   :maxdepth: 3

.. automodule:: psyneulink.core.components.functions.userdefinedfunction
   :members: UserDefinedFunction
   :exclude-members: Parameters
